==> ulyxex.0.1.1.with-tinyMce.zip: pages/code/admin_files_uploads.php <==
<?php
class MultipleUploads extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
		$this->allowed = array("7z","aac","ai","aif","aifc","aiff","arj","asf","asr","asx","au","avi","bin","bmp","cda","dcr","doc","dot","eps","flv","gif","gz","hqx","html","ico","jfif","jpe","jpeg","jpg","m4a","m4b","m4v","mid","mov","mp2","mp3","mp4","mpa","mpe","mpeg","mpg","odb","odc","odf","odg","odi","odm","odp","ods","odt","ogg","pdf","png","pps","ppt","ps","psd","ra","ram","rar","rm","rmi","rtf","sea","sit","sla","stc","std","sti","stw","swf","sxc","sxd","sxg","sxi","sxm","sxw","tar","tgz","tif","tiff","torrent","txt","vcf","wav","wcm","wdb","wks","wma","wmf","wmv","wps","wri","wrl","wrz","xaf","xbm","xla","xlc","xlm","xls","xlt","xlw","xml","xof","xpm","xsd","xsl","xwd","xspf","zip","pict");
	}
	public function file_type($fileName=null){
		$data = explode(".",$fileName);
		$result = array_pop($data);
		$result = strtolower($result);
		return $result;
	}
	public function upload() {
		$files = $_FILES['fileupload'];
		$i = 0;
		while($i < count($files) ){
			if ( !isset($files['name'][$i]) || empty($files['name'][$i]) ) {
				$i++; 
				echo $this->h->br($this->tr->ws("field").$i.$this->tr->wsp("empty")); 
				continue;
			}
			$fileName = $files['name'][$i];
			if (!empty($fileName)) {
					if ( !in_array($this->file_type($fileName),$this->allowed) ) exit($this->tr->w("not allowed file"));
					$send = move_uploaded_file($files['tmp_name'][$i],"files/".$fileName);
					echo $this->h->br($this->tr->ws("uploaded").$fileName); 
			}
			$i++;
		}
	}
	public function upload_form() {
		if (file_exists("files")) {
			$content = $this->h->input("hidden","add",1);
			$files = array();
			for ($i=0;$i<5;$i++) {
				$content .= $this->h->p($this->tr->ws("upload file").$this->h->input("file","fileupload[]","","size=30"));
			}
			$content .=  $this->h->p($this->h->input("submit","save",$this->tr->w("save")));
			$result = $this->h->form($content,"upload","post","admin.php?action=multiples_uploads","multipart/form-data");
			$result .= $this->h->p($this->h->b($this->tr->ws("files allowed:")).implode(" ",$this->allowed));
			return $result;
		} else {
			return "files directory doesn't exist";
		}
	}
}
?>

==> ulyxex.0.1.2.with-tinyMce.zip: pages/code/admin_files_uploads.php <==
<?php
class MultipleUploads extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
		$this->allowed = array("7z","aac","ai","aif","aifc","aiff","arj","asf","asr","asx","au","avi","bin","bmp","cda","dcr","doc","dot","eps","flv","gif","gz","hqx","html","ico","jfif","jpe","jpeg","jpg","m4a","m4b","m4v","mid","mov","mp2","mp3","mp4","mpa","mpe","mpeg","mpg","odb","odc","odf","odg","odi","odm","odp","ods","odt","ogg","pdf","png","pps","ppt","ps","psd","ra","ram","rar","rm","rmi","rtf","sea","sit","sla","stc","std","sti","stw","swf","sxc","sxd","sxg","sxi","sxm","sxw","tar","tgz","tif","tiff","torrent","txt","vcf","wav","wcm","wdb","wks","wma","wmf","wmv","wps","wri","wrl","wrz","xaf","xbm","xla","xlc","xlm","xls","xlt","xlw","xml","xof","xpm","xsd","xsl","xwd","xspf","zip","pict");
	}
	public function file_type($fileName=null){
		$data = explode(".",$fileName);
		$result = array_pop($data);
		$result = strtolower($result);
		return $result;
	}
	public function upload() {
		$files = $_FILES['fileupload'];
		$i = 0;
		while($i < count($files) ){
			if ( !isset($files['name'][$i]) || empty($files['name'][$i]) ) {
				$i++; 
				echo $this->h->br($this->tr->ws("field").$i.$this->tr->wsp("empty")); 
				continue;
			}
			$fileName = $files['name'][$i];
			if (!empty($fileName)) {
					if ( !in_array($this->file_type($fileName),$this->allowed) ) exit("not allowed file !");
					$send = move_uploaded_file($files['tmp_name'][$i],"files/".$fileName);
					echo $this->h->br($this->tr->ws("uploaded").$fileName); 
			}
			$i++;
		}
	}
	public function upload_form() {
		if (file_exists("files")) {
			$content = $this->h->input("hidden","add",1);
			$files = array();
			for ($i=0;$i<5;$i++) {
				$content .= $this->h->p($this->tr->ws("upload file").$this->h->input("file","fileupload[]","","size=30"));
			}
			$content .=  $this->h->p($this->h->input("submit","save",$this->tr->w("save")));
			$result = $this->h->form($content,"upload","post","admin.php?action=multiples_uploads","multipart/form-data");
			$result .= $this->h->p($this->h->b($this->tr->ws("files allowed:")).implode(" ",$this->allowed));
			return $result;
		} else {
			return "files directory doesn't exist";
		}
	}
}
?>
